XML Resume Library Authors

# XML Résumé Library Authors

The XML Résumé Library copyrighted, © 2000-2002 by Sean Kelly. See the copying conditions, license, and disclaimer.

## Core Team

Sean Kelly | Project Manager
Stewart Evans | Information Analyst/Designer
Bruce Christensen | Developer and Project Manager
Robert Dubinski | Developer
Olivier Eymere | Developer
Rob Kelley | Developer
Dave Lee | Developer
Brian May | Developer
Paul Sargent | Developer
Mark Miller | Developer
Nick Chalko | Developer

## Contributors

Vlad Korolev provided the plain text transformation.

Roel Vanhout suggested the date of birth element. Formatting of the date of birth will appear later.

Will Sargent contributed the cygwin shell script for those who don't like Makefiles on Windows.

Payam Mirrashidi contributed the Windows batch file for those who don't like cygwin on Windows.

Andre van Dijk contributed the Dutch translation layer.

And thanks go to Norman Walsh for unwittingly providing the the `iso-lat1.ent` file.